/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Webflow from "../../../index";
import { Redirects } from "../resources/redirects/client/Client";
import { Plans } from "../resources/plans/client/Client";
import { RobotsTxt } from "../resources/robotsTxt/client/Client";
import { WellKnown } from "../resources/wellKnown/client/Client";
import { ActivityLogs } from "../resources/activityLogs/client/Client";
import { Comments } from "../resources/comments/client/Client";
import { Scripts } from "../resources/scripts/client/Client";
export declare namespace Sites {
    interface Options {
        environment?: core.Supplier<environments.WebflowEnvironment | environments.WebflowEnvironmentUrls>;
        accessToken: core.Supplier<core.BearerToken>;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
/**
 * Sites are the sites in your Webflow workspace.
 */
export declare class Sites {
    protected readonly _options: Sites.Options;
    constructor(_options: Sites.Options);
    /**
     * Create a site.
     *
     * <Warning title="Enterprise Only">This endpoint requires an Enterprise workspace.</Warning>
     *
     * Required scope | `workspace:write`
     *
     * @param {string} workspaceId - Unique identifier for a Workspace
     * @param {Webflow.SitesCreateRequest} request
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.BadRequestError}
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.ForbiddenError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     * @throws {@link Webflow.InternalServerError}
     *
     * @example
     *     await client.sites.create("580e63e98c9a982ac9b8b741", {
     *         name: "The Hitchhiker's Guide to the Galaxy"
     *     })
     */
    create(workspaceId: string, request: Webflow.SitesCreateRequest, requestOptions?: Sites.RequestOptions): Promise<Webflow.Site>;
    /**
     * List of all sites the provided access token is able to access.
     *
     * Required scope | `sites:read`
     *
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     *
     * @example
     *     await client.sites.list()
     */
    list(requestOptions?: Sites.RequestOptions): Promise<Webflow.Sites>;
    /**
     * Get details of a site.
     *
     * Required scope | `sites:read`
     *
     * @param {string} siteId - Unique identifier for a Site
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.BadRequestError}
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     * @throws {@link Webflow.InternalServerError}
     *
     * @example
     *     await client.sites.get("580e63e98c9a982ac9b8b741")
     */
    get(siteId: string, requestOptions?: Sites.RequestOptions): Promise<Webflow.Site>;
    /**
     * Delete a site.
     *
     * <Warning title="Enterprise Only">This endpoint requires an Enterprise workspace.</Warning>
     *
     * Required scope | `sites:write`
     *
     * @param {string} siteId - Unique identifier for a Site
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.BadRequestError}
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.ForbiddenError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     * @throws {@link Webflow.InternalServerError}
     *
     * @example
     *     await client.sites.delete("580e63e98c9a982ac9b8b741")
     */
    delete(siteId: string, requestOptions?: Sites.RequestOptions): Promise<void>;
    /**
     * Update a site.
     *
     * <Warning title="Enterprise Only">This endpoint requires an Enterprise workspace.</Warning>
     *
     * Required scope | `sites:write`
     *
     * @param {string} siteId - Unique identifier for a Site
     * @param {Webflow.SitesUpdateRequest} request
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.BadRequestError}
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.ForbiddenError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     * @throws {@link Webflow.InternalServerError}
     *
     * @example
     *     await client.sites.update("580e63e98c9a982ac9b8b741")
     */
    update(siteId: string, request?: Webflow.SitesUpdateRequest, requestOptions?: Sites.RequestOptions): Promise<Webflow.Site>;
    /**
     * Get a list of all custom domains related to site.
     *
     * Required scope | `sites:read`
     *
     * @param {string} siteId - Unique identifier for a Site
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.ForbiddenError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     * @throws {@link Webflow.InternalServerError}
     *
     * @example
     *     await client.sites.getCustomDomain("580e63e98c9a982ac9b8b741")
     */
    getCustomDomain(siteId: string, requestOptions?: Sites.RequestOptions): Promise<Webflow.Domains>;
    /**
     * Publishes a site to one or more more domains.
     *
     * <Note title="Endpoint-specific rate limit">This endpoint has a limit of one successful publish queue per minute.</Note>
     *
     * Required scope | `sites:write`
     *
     * @param {string} siteId - Unique identifier for a Site
     * @param {Webflow.SitesPublishRequest} request
     * @param {Sites.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Webflow.BadRequestError}
     * @throws {@link Webflow.UnauthorizedError}
     * @throws {@link Webflow.ForbiddenError}
     * @throws {@link Webflow.NotFoundError}
     * @throws {@link Webflow.TooManyRequestsError}
     *
     * @example
     *     await client.sites.publish("580e63e98c9a982ac9b8b741")
     */
    publish(siteId: string, request?: Webflow.SitesPublishRequest, requestOptions?: Sites.RequestOptions): Promise<Webflow.SitesPublishResponse>;
    protected _redirects: Redirects | undefined;
    get redirects(): Redirects;
    protected _plans: Plans | undefined;
    get plans(): Plans;
    protected _robotsTxt: RobotsTxt | undefined;
    get robotsTxt(): RobotsTxt;
    protected _wellKnown: WellKnown | undefined;
    get wellKnown(): WellKnown;
    protected _activityLogs: ActivityLogs | undefined;
    get activityLogs(): ActivityLogs;
    protected _comments: Comments | undefined;
    get comments(): Comments;
    protected _scripts: Scripts | undefined;
    get scripts(): Scripts;
    protected _getAuthorizationHeader(): Promise<string>;
}
